require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_userrightsassignment',
  dscmeta_resource_friendly_name: 'UserRightsAssignment',
  dscmeta_resource_name: 'MSFT_UserRightsAssignment',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SecurityPolicyDsc',
  dscmeta_module_version: '2.10.0.0',
  docs: 'The DSC UserRightsAssignment resource type.
         Automatically generated from version 2.10.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to Force the change',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_policy: {
      type: "Enum['Create_a_token_object', 'create_a_token_object', 'Access_this_computer_from_the_network', 'access_this_computer_from_the_network', 'Change_the_system_time', 'change_the_system_time', 'Deny_log_on_as_a_batch_job', 'deny_log_on_as_a_batch_job', 'Deny_log_on_through_Remote_Desktop_Services', 'deny_log_on_through_remote_desktop_services', 'Create_global_objects', 'create_global_objects', 'Remove_computer_from_docking_station', 'remove_computer_from_docking_station', 'Deny_access_to_this_computer_from_the_network', 'deny_access_to_this_computer_from_the_network', 'Act_as_part_of_the_operating_system', 'act_as_part_of_the_operating_system', 'Modify_firmware_environment_values', 'modify_firmware_environment_values', 'Deny_log_on_locally', 'deny_log_on_locally', 'Access_Credential_Manager_as_a_trusted_caller', 'access_credential_manager_as_a_trusted_caller', 'Restore_files_and_directories', 'restore_files_and_directories', 'Change_the_time_zone', 'change_the_time_zone', 'Replace_a_process_level_token', 'replace_a_process_level_token', 'Manage_auditing_and_security_log', 'manage_auditing_and_security_log', 'Create_symbolic_links', 'create_symbolic_links', 'Modify_an_object_label', 'modify_an_object_label', 'Enable_computer_and_user_accounts_to_be_trusted_for_delegation', 'enable_computer_and_user_accounts_to_be_trusted_for_delegation', 'Generate_security_audits', 'generate_security_audits', 'Increase_a_process_working_set', 'increase_a_process_working_set', 'Take_ownership_of_files_or_other_objects', 'take_ownership_of_files_or_other_objects', 'Bypass_traverse_checking', 'bypass_traverse_checking', 'Log_on_as_a_service', 'log_on_as_a_service', 'Shut_down_the_system', 'shut_down_the_system', 'Lock_pages_in_memory', 'lock_pages_in_memory', 'Impersonate_a_client_after_authentication', 'impersonate_a_client_after_authentication', 'Profile_system_performance', 'profile_system_performance', 'Debug_programs', 'debug_programs', 'Profile_single_process', 'profile_single_process', 'Allow_log_on_through_Remote_Desktop_Services', 'allow_log_on_through_remote_desktop_services', 'Allow_log_on_locally', 'allow_log_on_locally', 'Increase_scheduling_priority', 'increase_scheduling_priority', 'Synchronize_directory_service_data', 'synchronize_directory_service_data', 'Add_workstations_to_domain', 'add_workstations_to_domain', 'Adjust_memory_quotas_for_a_process', 'adjust_memory_quotas_for_a_process', 'Obtain_an_impersonation_token_for_another_user_in_the_same_session', 'obtain_an_impersonation_token_for_another_user_in_the_same_session', 'Perform_volume_maintenance_tasks', 'perform_volume_maintenance_tasks', 'Load_and_unload_device_drivers', 'load_and_unload_device_drivers', 'Force_shutdown_from_a_remote_system', 'force_shutdown_from_a_remote_system', 'Back_up_files_and_directories', 'back_up_files_and_directories', 'Create_a_pagefile', 'create_a_pagefile', 'Deny_log_on_as_a_service', 'deny_log_on_as_a_service', 'Log_on_as_a_batch_job', 'log_on_as_a_batch_job', 'Create_permanent_shared_objects', 'create_permanent_shared_objects']",
      desc: 'The policy name of the user rights assignment to be configured.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_identity: {
      type: 'Array[String]',
      desc: 'The identity of the user or group to be added or removed from the user rights assignment.',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Desired state of resource.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
